==> sancho-3.4.1.tgz: package/esm/Hooks/use-infinite-scroll.js <==
import * as React from "react";
import rafSchd from "raf-schd";
export var useInfiniteScroll = function (_a) {
    var container = _a.container, onFetch = _a.onFetch, hasMore = _a.hasMore, _b = _a.disabled, disabled = _b === void 0 ? false : _b, _c = _a.triggerOffset, triggerOffset = _c === void 0 ? 300 : _c;
    var _d = React.useState(false), fetching = _d[0], setFetching = _d[1];
    var onScroll = React.useCallback(rafSchd(function () {
        // check container
        if (container) {
            if (container.current) {
                if (container.current &&
                    !fetching &&
                    hasMore &&
                    container.current.scrollTop +
                        container.current.clientHeight +
                        triggerOffset >=
                        container.current.scrollHeight) {
                    setFetching(true);
                }
            }
            // check window
        }
        else {
            if (!fetching &&
                hasMore &&
                window.innerHeight + document.documentElement.scrollTop >=
                    document.documentElement.offsetHeight - triggerOffset) {
                setFetching(true);
            }
        }
    }), [fetching, hasMore]);
    // bind our scroll listener
    React.useEffect(function () {
        if (disabled) {
            return;
        }
        // this is so ugly uggh
        // bind our scroll event to either container or window
        if (container) {
            if (container.current) {
                container.current.addEventListener("scroll", onScroll);
            }
        }
        else {
            window.addEventListener("scroll", onScroll);
        }
        // unbind our scroll event
        return function () {
            if (container) {
                if (container.current) {
                    container.current.removeEventListener("scroll", onScroll);
                }
            }
            else {
                window.removeEventListener("scroll", onScroll);
            }
        };
    }, [container, onScroll, disabled]);
    React.useEffect(function () {
        if (fetching) {
            onFetch().finally(function () { return setFetching(false); });
        }
    }, [fetching]);
    return [fetching, setFetching];
};

==> sancho-3.5.0.tgz: package/esm/Hooks/use-infinite-scroll.js <==
import * as React from "react";
import rafSchd from "raf-schd";
export var useInfiniteScroll = function (_a) {
    var container = _a.container, onFetch = _a.onFetch, hasMore = _a.hasMore, _b = _a.disabled, disabled = _b === void 0 ? false : _b, _c = _a.triggerOffset, triggerOffset = _c === void 0 ? 300 : _c;
    var _d = React.useState(false), fetching = _d[0], setFetching = _d[1];
    var onScroll = React.useCallback(rafSchd(function () {
        // check container
        if (container) {
            if (container.current) {
                if (container.current &&
                    !fetching &&
                    hasMore &&
                    container.current.scrollTop +
                        container.current.clientHeight +
                        triggerOffset >=
                        container.current.scrollHeight) {
                    setFetching(true);
                }
            }
            // check window
        }
        else {
            if (!fetching &&
                hasMore &&
                window.innerHeight + document.documentElement.scrollTop >=
                    document.documentElement.offsetHeight - triggerOffset) {
                setFetching(true);
            }
        }
    }), [fetching, hasMore]);
    // bind our scroll listener
    React.useEffect(function () {
        if (disabled) {
            return;
        }
        // this is so ugly uggh
        // bind our scroll event to either container or window
        if (container) {
            if (container.current) {
                container.current.addEventListener("scroll", onScroll);
            }
        }
        else {
            window.addEventListener("scroll", onScroll);
        }
        // unbind our scroll event
        return function () {
            if (container) {
                if (container.current) {
                    container.current.removeEventListener("scroll", onScroll);
                }
            }
            else {
                window.removeEventListener("scroll", onScroll);
            }
        };
    }, [onScroll, disabled]);
    React.useEffect(function () {
        if (fetching) {
            onFetch().finally(function () { return setFetching(false); });
        }
    }, [fetching]);
    return [fetching, setFetching];
};
